@@ -26,6 +26,9 @@ from keras_cv_attention_models.resnet_family import regnet
 from keras_cv_attention_models import uniformer
 from keras_cv_attention_models import volo
 from keras_cv_attention_models import yolox
+from keras_cv_attention_models import yolor
 from keras_cv_attention_models import download_and_load
 from keras_cv_attention_models import visualizing
 from keras_cv_attention_models import imagenet
+from keras_cv_attention_models import coco
+from keras_cv_attention_models import test_images
