@@ -314,7 +314,7 @@ def init_dataset(
     anchor_scale=4,  # Force using 1 if use_anchor_free_mode
     anchor_grid_zero_start="auto",  # False for anchor_free_mode, True for others.
     rescale_mode="torch",  # rescale mode, ["tf", "torch"], or specific `(mean, std)` like `(128.0, 128.0)`
-    random_crop_mode=1.0, # 0 for eval mode, (0, 1) for random crop, 1 for random largest crop, > 1 for random scale
+    random_crop_mode=1.0,  # 0 for eval mode, (0, 1) for random crop, 1 for random largest crop, > 1 for random scale
     mosaic_mix_prob=0.0,
     resize_method="bilinear",  # ["bilinear", "bicubic"]
     resize_antialias=False,
@@ -395,7 +395,7 @@ def draw_bboxes(bboxes, ax=None):
     return ax
 
 
-def show_image_with_bboxes(image, bboxes, labels=None, confidences=None, ax=None, label_font_size=8, num_classes=80):
+def show_image_with_bboxes(image, bboxes, labels=None, confidences=None, is_bbox_width_first=False, ax=None, label_font_size=8, num_classes=80):
     import matplotlib.pyplot as plt
     import numpy as np
 
@@ -403,6 +403,8 @@ def show_image_with_bboxes(image, bboxes, labels=None, confidences=None, ax=None
         fig, ax = plt.subplots()
     ax.imshow(image)
     bboxes = np.array(bboxes)
+    if is_bbox_width_first:
+        bboxes = bboxes[:, [1, 0, 3, 2]]
     for id, bb in enumerate(bboxes):
         # bbox is [top, left, bottom, right]
         bb = [bb[0] * image.shape[0], bb[1] * image.shape[1], bb[2] * image.shape[0], bb[3] * image.shape[1]]
